#
# PySNMP MIB module DIFFSERV-MIB (http://snmplabs.com/pysmi)
# ASN.1 source file:///usr/share/snmp/mibs/ietf/DIFFSERV-MIB
# Produced by pysmi-1.1.10 at Mon Oct  9 12:14:08 2023
# On host simtve-ThinkPad-X1-Carbon-Gen-9 platform Linux version 5.15.0-84-generic by user simon
# Using Python version 3.9.18 (main, Aug 25 2023, 13:20:04) 
#
Integer, ObjectIdentifier, OctetString = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
NamedValues, = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
ConstraintsUnion, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, SingleValueConstraint = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "SingleValueConstraint")
Dscp, DscpOrAny = mibBuilder.importSymbols("DIFFSERV-DSCP-TC", "Dscp", "DscpOrAny")
ifIndex, InterfaceIndexOrZero = mibBuilder.importSymbols("IF-MIB", "ifIndex", "InterfaceIndexOrZero")
InetAddressType, InetAddress, InetPortNumber, InetAddressPrefixLength = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress", "InetPortNumber", "InetAddressPrefixLength")
BurstSize, = mibBuilder.importSymbols("INTEGRATED-SERVICES-MIB", "BurstSize")
NotificationGroup, ObjectGroup, ModuleCompliance = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
IpAddress, ModuleIdentity, Bits, MibIdentifier, Counter64, iso, Integer32, TimeTicks, NotificationType, Unsigned32, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, Gauge32, Counter32, zeroDotZero = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "ModuleIdentity", "Bits", "MibIdentifier", "Counter64", "iso", "Integer32", "TimeTicks", "NotificationType", "Unsigned32", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity", "Gauge32", "Counter32", "zeroDotZero")
RowPointer, AutonomousType, DisplayString, TextualConvention, StorageType, RowStatus = mibBuilder.importSymbols("SNMPv2-TC", "RowPointer", "AutonomousType", "DisplayString", "TextualConvention", "StorageType", "RowStatus")
diffServMib = ModuleIdentity((1, 3, 6, 1, 2, 1, 97))
diffServMib.setRevisions(('2002-02-07 00:00',))

if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    if mibBuilder.loadTexts: diffServMib.setRevisionsDescriptions(('Initial version, published as RFC 3289.',))
if mibBuilder.loadTexts: diffServMib.setLastUpdated('200202070000Z')
if mibBuilder.loadTexts: diffServMib.setOrganization('IETF Differentiated Services WG')
if mibBuilder.loadTexts: diffServMib.setContactInfo(' Fred Baker Cisco Systems 1121 Via Del Rey Santa Barbara, CA 93117, USA E-mail: fred@cisco.com Kwok Ho Chan Nortel Networks 600 Technology Park Drive Billerica, MA 01821, USA E-mail: khchan@nortelnetworks.com Andrew Smith Harbour Networks Jiuling Building 21 North Xisanhuan Ave. Beijing, 100089, PRC E-mail: ah_smith@acm.org Differentiated Services Working Group: diffserv@ietf.org')
if mibBuilder.loadTexts: diffServMib.setDescription('This MIB defines the objects necessary to manage a device that uses the Differentiated Services Architecture described in RFC 2475. The Conceptual Model of a Differentiated Services Router provides supporting information on how such a router is modeled.')
diffServMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1))
diffServMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 2))
diffServMIBAdmin = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 3))
class IndexInteger(TextualConvention, Unsigned32):
    description = 'An integer which may be used as a table index.'
    status = 'current'
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec + ValueRangeConstraint(1, 4294967295)

class IndexIntegerNextFree(TextualConvention, Unsigned32):
    description = 'An integer which may be used as a new Index in a table. The special value of 0 indicates that no more new entries can be created in the relevant table. When a MIB is used for configuration, an object with this SYNTAX always contains a legal value (if non-zero) for an index that is not currently used in the relevant table. The Command Generator (Network Management Application) reads this variable and uses the (non-zero) value read when creating a new row with an SNMP SET. When the SET is performed, the Command Responder (agent) must determine whether the value is indeed still unused; Two Network Management Applications may attempt to create a row (configuration entry) simultaneously and use the same value. If it is currently unused, the SET succeeds and the Command Responder (agent) changes the value of this object, according to an implementation-specific algorithm. If the value is in use, however, the SET fails. The Network Management Application must then re-read this variable to obtain a new usable value. An OBJECT-TYPE definition using this SYNTAX MUST specify the relevant table for which the object is providing this functionality.'
    status = 'current'
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec + ValueRangeConstraint(0, 4294967295)

class IfDirection(TextualConvention, Integer32):
    description = "IfDirection specifies a direction of data travel on an interface. 'inbound' traffic is operated on during reception from the interface, while 'outbound' traffic is operated on prior to transmission on the interface."
    status = 'current'
    subtypeSpec = Integer32.subtypeSpec + ConstraintsUnion(SingleValueConstraint(1, 2))
    namedValues = NamedValues(("inbound", 1), ("outbound", 2))

diffServDataPath = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 1))
diffServDataPathTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 1, 1), )
if mibBuilder.loadTexts: diffServDataPathTable.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathTable.setDescription('The data path table contains RowPointers indicating the start of the functional data path for each interface and traffic direction in this device. These may merge, or be separated into parallel data paths.')
diffServDataPathEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DIFFSERV-MIB", "diffServDataPathIfDirection"))
if mibBuilder.loadTexts: diffServDataPathEntry.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathEntry.setDescription('An entry in the data path table indicates the start of a single Differentiated Services Functional Data Path in this device. These are associated with individual interfaces, logical or physical, and therefore are instantiated by ifIndex. Therefore, the interface index must have been assigned, according to the procedures applicable to that, before it can be meaningfully used. Generally, this means that the interface must exist. When diffServDataPathStorage is of type nonVolatile, however, this may reflect the configuration for an interface whose ifIndex has been assigned but for which the supporting implementation is not currently present.')
diffServDataPathIfDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 1, 1, 1, 1), IfDirection())
if mibBuilder.loadTexts: diffServDataPathIfDirection.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathIfDirection.setDescription('IfDirection specifies whether the reception or transmission path for this interface is in view.')
diffServDataPathStart = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 1, 1, 1, 2), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServDataPathStart.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathStart.setDescription('This selects the first Differentiated Services Functional Data Path Element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServAlgDropEntry diffServQEntry A value of zeroDotZero in this attribute indicates that no Differentiated Services treatment is performed on traffic of this data path. A pointer with the value zeroDotZero normally terminates a functional data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServDataPathStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 1, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServDataPathStorage.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServDataPathStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 1, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServDataPathStatus.setStatus('current')
if mibBuilder.loadTexts: diffServDataPathStatus.setDescription('The status of this conceptual row. All writable objects in this row may be modified at any time.')
diffServClassifier = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 2))
diffServClfrNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 2, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServClfrNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServClfrNextFree.setDescription('This object contains an unused value for diffServClfrId, or a zero to indicate that none exist.')
diffServClfrTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 2, 2), )
if mibBuilder.loadTexts: diffServClfrTable.setStatus('current')
if mibBuilder.loadTexts: diffServClfrTable.setDescription('This table enumerates all the diffserv classifier functional data path elements of this device. The actual classification definitions are defined in diffServClfrElementTable entries belonging to each classifier. An entry in this table, pointed to by a RowPointer specifying an instance of diffServClfrStatus, is frequently used as the name for a set of classifier elements, which all use the index diffServClfrId. Per the semantics of the classifier element table, these entries constitute one or more unordered sets of tests which may be simultaneously applied to a message to classify it. The primary function of this table is to ensure that the value of diffServClfrId is unique before attempting to use it in creating a diffServClfrElementEntry. Therefore, the diffServClfrEntry must be created on the same SET as the diffServClfrElementEntry, or before the diffServClfrElementEntry is created.')
diffServClfrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 2, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServClfrId"))
if mibBuilder.loadTexts: diffServClfrEntry.setStatus('current')
if mibBuilder.loadTexts: diffServClfrEntry.setDescription("An entry in the classifier table describes a single classifier. All classifier elements belonging to the same classifier use the classifier's diffServClfrId as part of their index.")
diffServClfrId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServClfrId.setStatus('current')
if mibBuilder.loadTexts: diffServClfrId.setDescription('An index that enumerates the classifier entries. Managers should obtain new values for row creation in this table by reading diffServClfrNextFree.')
diffServClfrStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 2, 1, 2), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrStorage.setStatus('current')
if mibBuilder.loadTexts: diffServClfrStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServClfrStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrStatus.setStatus('current')
if mibBuilder.loadTexts: diffServClfrStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServClfrElementNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 2, 3), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServClfrElementNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementNextFree.setDescription('This object contains an unused value for diffServClfrElementId, or a zero to indicate that none exist.')
diffServClfrElementTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 2, 4), )
if mibBuilder.loadTexts: diffServClfrElementTable.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementTable.setDescription('The classifier element table enumerates the relationship between classification patterns and subsequent downstream Differentiated Services Functional Data Path elements. diffServClfrElementSpecific points to a filter that specifies the classification parameters. A classifier may use filter tables of different types together. One example of a filter table defined in this MIB is diffServMultiFieldClfrTable, for IP Multi-Field Classifiers (MFCs). Such an entry might identify anything from a single micro-flow (an identifiable sub-session packet stream directed from one sending transport to the receiving transport or transports), or aggregates of those such as the traffic from a host, traffic for an application, or traffic between two hosts using an application and a given DSCP. The standard Behavior Aggregate used in the Differentiated Services Architecture is encoded as a degenerate case of such an aggregate - the traffic using a particular DSCP value. Filter tables for other filter types may be defined elsewhere.')
diffServClfrElementEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServClfrId"), (0, "DIFFSERV-MIB", "diffServClfrElementId"))
if mibBuilder.loadTexts: diffServClfrElementEntry.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementEntry.setDescription('An entry in the classifier element table describes a single element of the classifier.')
diffServClfrElementId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServClfrElementId.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementId.setDescription('An index that enumerates the Classifier Element entries. Managers obtain new values for row creation in this table by reading diffServClfrElementNextFree.')
diffServClfrElementPrecedence = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrElementPrecedence.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementPrecedence.setDescription('The relative order in which classifier elements are applied: higher numbers represent classifier element with higher precedence. Classifier elements with the same order must be unambiguous i.e. they must define non-overlapping patterns, and are considered to be applied simultaneously to the traffic stream. Classifier elements with different order may overlap in their filters: the classifier element with the highest order that matches is taken. On a given interface, there must be a complete classifier in place at all times in the ingress direction. This means one or more filters must match any possible pattern. There is no such requirement in the egress direction.')
diffServClfrElementNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 3), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrElementNext.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementNext.setDescription('This attribute provides one branch of the fan-out functionality of a classifier described in the Informal Differentiated Services Model section 4.1. This selects the next Differentiated Services Functional Data Path Element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServAlgDropEntry diffServQEntry A value of zeroDotZero in this attribute indicates no further Differentiated Services treatment is performed on traffic of this data path. The use of zeroDotZero is the normal usage for the last functional data path element of the current data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServClfrElementSpecific = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrElementSpecific.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementSpecific.setDescription('A pointer to a valid entry in another table, filter table, that describes the applicable classification parameters, e.g. an entry in diffServMultiFieldClfrTable. The value zeroDotZero is interpreted to match anything not matched by another classifier element - only one such entry may exist for each classifier. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the element is ignored.')
diffServClfrElementStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrElementStorage.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServClfrElementStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 4, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServClfrElementStatus.setStatus('current')
if mibBuilder.loadTexts: diffServClfrElementStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServMultiFieldClfrNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 2, 5), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServMultiFieldClfrNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrNextFree.setDescription('This object contains an unused value for diffServMultiFieldClfrId, or a zero to indicate that none exist.')
diffServMultiFieldClfrTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 2, 6), )
if mibBuilder.loadTexts: diffServMultiFieldClfrTable.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrTable.setDescription('A table of IP Multi-field Classifier filter entries that a system may use to identify IP traffic.')
diffServMultiFieldClfrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServMultiFieldClfrId"))
if mibBuilder.loadTexts: diffServMultiFieldClfrEntry.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrEntry.setDescription('An IP Multi-field Classifier entry describes a single filter.')
diffServMultiFieldClfrId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServMultiFieldClfrId.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrId.setDescription('An index that enumerates the MultiField Classifier filter entries. Managers obtain new values for row creation in this table by reading diffServMultiFieldClfrNextFree.')
diffServMultiFieldClfrAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 2), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrAddrType.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrAddrType.setDescription('The type of IP address used by this classifier entry. While other types of addresses are defined in the InetAddressType textual convention, and DNS names, a classifier can only look at packets on the wire. Therefore, this object is limited to IPv4 and IPv6 addresses.')
diffServMultiFieldClfrDstAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 3), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrDstAddr.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrDstAddr.setDescription("The IP address to match against the packet's destination IP address. This may not be a DNS name, but may be an IPv4 or IPv6 prefix. diffServMultiFieldClfrDstPrefixLength indicates the number of bits that are relevant.")
diffServMultiFieldClfrDstPrefixLength = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 4), InetAddressPrefixLength()).setUnits('bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrDstPrefixLength.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrDstPrefixLength.setDescription('The length of the CIDR Prefix carried in diffServMultiFieldClfrDstAddr. In IPv4 addresses, a length of 0 indicates a match of any address; a length of 32 indicates a match of a single host address, and a length between 0 and 32 indicates the use of a CIDR Prefix. IPv6 is similar, except that prefix lengths range from 0..128.')
diffServMultiFieldClfrSrcAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 5), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcAddr.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcAddr.setDescription("The IP address to match against the packet's source IP address. This may not be a DNS name, but may be an IPv4 or IPv6 prefix. diffServMultiFieldClfrSrcPrefixLength indicates the number of bits that are relevant.")
diffServMultiFieldClfrSrcPrefixLength = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 6), InetAddressPrefixLength()).setUnits('bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcPrefixLength.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcPrefixLength.setDescription('The length of the CIDR Prefix carried in diffServMultiFieldClfrSrcAddr. In IPv4 addresses, a length of 0 indicates a match of any address; a length of 32 indicates a match of a single host address, and a length between 0 and 32 indicates the use of a CIDR Prefix. IPv6 is similar, except that prefix lengths range from 0..128.')
diffServMultiFieldClfrDscp = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 7), DscpOrAny().clone(-1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrDscp.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrDscp.setDescription('The value that the DSCP in the packet must have to match this entry. A value of -1 indicates that a specific DSCP value has not been defined and thus all DSCP values are considered a match.')
diffServMultiFieldClfrFlowId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 1048575))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrFlowId.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrFlowId.setDescription('The flow identifier in an IPv6 header.')
diffServMultiFieldClfrProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 9), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 255)).clone(255)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrProtocol.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrProtocol.setDescription('The IP protocol to match against the IPv4 protocol number or the IPv6 Next- Header number in the packet. A value of 255 means match all. Note the protocol number of 255 is reserved by IANA, and Next-Header number of 0 is used in IPv6.')
diffServMultiFieldClfrDstL4PortMin = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 10), InetPortNumber()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrDstL4PortMin.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrDstL4PortMin.setDescription('The minimum value that the layer-4 destination port number in the packet must have in order to match this classifier entry.')
diffServMultiFieldClfrDstL4PortMax = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 11), InetPortNumber().clone(65535)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrDstL4PortMax.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrDstL4PortMax.setDescription('The maximum value that the layer-4 destination port number in the packet must have in order to match this classifier entry. This value must be equal to or greater than the value specified for this entry in diffServMultiFieldClfrDstL4PortMin.')
diffServMultiFieldClfrSrcL4PortMin = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 12), InetPortNumber()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcL4PortMin.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcL4PortMin.setDescription('The minimum value that the layer-4 source port number in the packet must have in order to match this classifier entry.')
diffServMultiFieldClfrSrcL4PortMax = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 13), InetPortNumber().clone(65535)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcL4PortMax.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrSrcL4PortMax.setDescription('The maximum value that the layer-4 source port number in the packet must have in order to match this classifier entry. This value must be equal to or greater than the value specified for this entry in diffServMultiFieldClfrSrcL4PortMin.')
diffServMultiFieldClfrStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 14), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrStorage.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServMultiFieldClfrStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 2, 6, 1, 15), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMultiFieldClfrStatus.setStatus('current')
if mibBuilder.loadTexts: diffServMultiFieldClfrStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServMeter = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 3))
diffServMeterNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 3, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServMeterNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServMeterNextFree.setDescription('This object contains an unused value for diffServMeterId, or a zero to indicate that none exist.')
diffServMeterTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 3, 2), )
if mibBuilder.loadTexts: diffServMeterTable.setStatus('current')
if mibBuilder.loadTexts: diffServMeterTable.setDescription('This table enumerates specific meters that a system may use to police a stream of traffic. The traffic stream to be metered is determined by the Differentiated Services Functional Data Path Element(s) upstream of the meter i.e. by the object(s) that point to each entry in this table. This may include all traffic on an interface. Specific meter details are to be found in table entry referenced by diffServMeterSpecific.')
diffServMeterEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServMeterId"))
if mibBuilder.loadTexts: diffServMeterEntry.setStatus('current')
if mibBuilder.loadTexts: diffServMeterEntry.setDescription('An entry in the meter table describes a single conformance level of a meter.')
diffServMeterId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServMeterId.setStatus('current')
if mibBuilder.loadTexts: diffServMeterId.setDescription('An index that enumerates the Meter entries. Managers obtain new values for row creation in this table by reading diffServMeterNextFree.')
diffServMeterSucceedNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 2), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMeterSucceedNext.setStatus('current')
if mibBuilder.loadTexts: diffServMeterSucceedNext.setDescription('If the traffic does conform, this selects the next Differentiated Services Functional Data Path element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServAlgDropEntry diffServQEntry A value of zeroDotZero in this attribute indicates that no further Differentiated Services treatment is performed on traffic of this data path. The use of zeroDotZero is the normal usage for the last functional data path element of the current data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServMeterFailNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 3), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMeterFailNext.setStatus('current')
if mibBuilder.loadTexts: diffServMeterFailNext.setDescription('If the traffic does not conform, this selects the next Differentiated Services Functional Data Path element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServAlgDropEntry diffServQEntry A value of zeroDotZero in this attribute indicates no further Differentiated Services treatment is performed on traffic of this data path. The use of zeroDotZero is the normal usage for the last functional data path element of the current data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServMeterSpecific = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMeterSpecific.setStatus('current')
if mibBuilder.loadTexts: diffServMeterSpecific.setDescription('This indicates the behavior of the meter by pointing to an entry containing detailed parameters. Note that entries in that specific table must be managed explicitly. For example, diffServMeterSpecific may point to an entry in diffServTBParamTable, which contains an instance of a single set of Token Bucket parameters. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the meter always succeeds.')
diffServMeterStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMeterStorage.setStatus('current')
if mibBuilder.loadTexts: diffServMeterStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServMeterStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 3, 2, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMeterStatus.setStatus('current')
if mibBuilder.loadTexts: diffServMeterStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServTBParam = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 4))
diffServTBParamNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 4, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServTBParamNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamNextFree.setDescription('This object contains an unused value for diffServTBParamId, or a zero to indicate that none exist.')
diffServTBParamTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 4, 2), )
if mibBuilder.loadTexts: diffServTBParamTable.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamTable.setDescription('This table enumerates a single set of token bucket meter parameters that a system may use to police a stream of traffic. Such meters are modeled here as having a single rate and a single burst size. Multiple entries are used when multiple rates/burst sizes are needed.')
diffServTBParamEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServTBParamId"))
if mibBuilder.loadTexts: diffServTBParamEntry.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamEntry.setDescription('An entry that describes a single set of token bucket parameters.')
diffServTBParamId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServTBParamId.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamId.setDescription('An index that enumerates the Token Bucket Parameter entries. Managers obtain new values for row creation in this table by reading diffServTBParamNextFree.')
diffServTBParamType = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 2), AutonomousType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamType.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamType.setDescription('The Metering algorithm associated with the Token Bucket parameters. zeroDotZero indicates this is unknown. Standard values for generic algorithms: diffServTBParamSimpleTokenBucket, diffServTBParamAvgRate, diffServTBParamSrTCMBlind, diffServTBParamSrTCMAware, diffServTBParamTrTCMBlind, diffServTBParamTrTCMAware, and diffServTBParamTswTCM are specified in this MIB as OBJECT- IDENTITYs; additional values may be further specified in other MIBs.')
diffServTBParamRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamRate.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamRate.setDescription('The token-bucket rate, in kilobits per second (kbps). This attribute is used for: 1. CIR in RFC 2697 for srTCM 2. CIR and PIR in RFC 2698 for trTCM 3. CTR and PTR in RFC 2859 for TSWTCM 4. AverageRate in RFC 3290.')
diffServTBParamBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 4), BurstSize()).setUnits('Bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamBurstSize.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamBurstSize.setDescription('The maximum number of bytes in a single transmission burst. This attribute is used for: 1. CBS and EBS in RFC 2697 for srTCM 2. CBS and PBS in RFC 2698 for trTCM 3. Burst Size in RFC 3290.')
diffServTBParamInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('microseconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamInterval.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamInterval.setDescription('The time interval used with the token bucket. For: 1. Average Rate Meter, the Informal Differentiated Services Model section 5.2.1, - Delta. 2. Simple Token Bucket Meter, the Informal Differentiated Services Model section 5.1, - time interval t. 3. RFC 2859 TSWTCM, - AVG_INTERVAL. 4. RFC 2697 srTCM, RFC 2698 trTCM, - token bucket update time interval.')
diffServTBParamStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamStorage.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServTBParamStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 4, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServTBParamStatus.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServTBMeters = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 3, 1))
diffServTBParamSimpleTokenBucket = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 1))
if mibBuilder.loadTexts: diffServTBParamSimpleTokenBucket.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamSimpleTokenBucket.setDescription('Two Parameter Token Bucket Meter as described in the Informal Differentiated Services Model section 5.2.3.')
diffServTBParamAvgRate = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 2))
if mibBuilder.loadTexts: diffServTBParamAvgRate.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamAvgRate.setDescription('Average Rate Meter as described in the Informal Differentiated Services Model section 5.2.1.')
diffServTBParamSrTCMBlind = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 3))
if mibBuilder.loadTexts: diffServTBParamSrTCMBlind.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamSrTCMBlind.setDescription("Single Rate Three Color Marker Metering as defined by RFC 2697, in the `Color Blind' mode as described by the RFC.")
if mibBuilder.loadTexts: diffServTBParamSrTCMBlind.setReference('RFC 2697')
diffServTBParamSrTCMAware = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 4))
if mibBuilder.loadTexts: diffServTBParamSrTCMAware.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamSrTCMAware.setDescription("Single Rate Three Color Marker Metering as defined by RFC 2697, in the `Color Aware' mode as described by the RFC.")
if mibBuilder.loadTexts: diffServTBParamSrTCMAware.setReference('RFC 2697')
diffServTBParamTrTCMBlind = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 5))
if mibBuilder.loadTexts: diffServTBParamTrTCMBlind.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamTrTCMBlind.setDescription("Two Rate Three Color Marker Metering as defined by RFC 2698, in the `Color Blind' mode as described by the RFC.")
if mibBuilder.loadTexts: diffServTBParamTrTCMBlind.setReference('RFC 2698')
diffServTBParamTrTCMAware = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 6))
if mibBuilder.loadTexts: diffServTBParamTrTCMAware.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamTrTCMAware.setDescription("Two Rate Three Color Marker Metering as defined by RFC 2698, in the `Color Aware' mode as described by the RFC.")
if mibBuilder.loadTexts: diffServTBParamTrTCMAware.setReference('RFC 2698')
diffServTBParamTswTCM = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 1, 7))
if mibBuilder.loadTexts: diffServTBParamTswTCM.setStatus('current')
if mibBuilder.loadTexts: diffServTBParamTswTCM.setDescription('Time Sliding Window Three Color Marker Metering as defined by RFC 2859.')
if mibBuilder.loadTexts: diffServTBParamTswTCM.setReference('RFC 2859')
diffServAction = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 5))
diffServActionNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 5, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServActionNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServActionNextFree.setDescription('This object contains an unused value for diffServActionId, or a zero to indicate that none exist.')
diffServActionTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 5, 2), )
if mibBuilder.loadTexts: diffServActionTable.setStatus('current')
if mibBuilder.loadTexts: diffServActionTable.setDescription('The Action Table enumerates actions that can be performed to a stream of traffic. Multiple actions can be concatenated. For example, traffic exiting from a meter may be counted, marked, and potentially dropped before entering a queue. Specific actions are indicated by diffServActionSpecific which points to an entry of a specific action type parameterizing the action in detail.')
diffServActionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServActionId"))
if mibBuilder.loadTexts: diffServActionEntry.setStatus('current')
if mibBuilder.loadTexts: diffServActionEntry.setDescription('Each entry in the action table allows description of one specific action to be applied to traffic.')
diffServActionId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServActionId.setStatus('current')
if mibBuilder.loadTexts: diffServActionId.setDescription('An index that enumerates the Action entries. Managers obtain new values for row creation in this table by reading diffServActionNextFree.')
diffServActionInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 2), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServActionInterface.setStatus('current')
if mibBuilder.loadTexts: diffServActionInterface.setDescription("The interface index (value of ifIndex) that this action occurs on. This may be derived from the diffServDataPathStartEntry's index by extension through the various RowPointers. However, as this may be difficult for a network management station, it is placed here as well. If this is indeterminate, the value is zero. This is of especial relevance when reporting the counters which may apply to traffic crossing an interface: diffServCountActOctets, diffServCountActPkts, diffServAlgDropOctets, diffServAlgDropPkts, diffServAlgRandomDropOctets, and diffServAlgRandomDropPkts. It is also especially relevant to the queue and scheduler which may be subsequently applied.")
diffServActionNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 3), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServActionNext.setStatus('current')
if mibBuilder.loadTexts: diffServActionNext.setDescription('This selects the next Differentiated Services Functional Data Path Element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServAlgDropEntry diffServQEntry A value of zeroDotZero in this attribute indicates no further Differentiated Services treatment is performed on traffic of this data path. The use of zeroDotZero is the normal usage for the last functional data path element of the current data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServActionSpecific = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServActionSpecific.setStatus('current')
if mibBuilder.loadTexts: diffServActionSpecific.setDescription('A pointer to an object instance providing additional information for the type of action indicated by this action table entry. For the standard actions defined by this MIB module, this should point to either a diffServDscpMarkActEntry or a diffServCountActEntry. For other actions, it may point to an object instance defined in some other MIB. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the Meter should be treated as if it were not present. This may lead to incorrect policy behavior.')
diffServActionStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServActionStorage.setStatus('current')
if mibBuilder.loadTexts: diffServActionStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServActionStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 2, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServActionStatus.setStatus('current')
if mibBuilder.loadTexts: diffServActionStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServDscpMarkActTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 5, 3), )
if mibBuilder.loadTexts: diffServDscpMarkActTable.setStatus('current')
if mibBuilder.loadTexts: diffServDscpMarkActTable.setDescription('This table enumerates specific DSCPs used for marking or remarking the DSCP field of IP packets. The entries of this table may be referenced by a diffServActionSpecific attribute.')
diffServDscpMarkActEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 5, 3, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServDscpMarkActDscp"))
if mibBuilder.loadTexts: diffServDscpMarkActEntry.setStatus('current')
if mibBuilder.loadTexts: diffServDscpMarkActEntry.setDescription('An entry in the DSCP mark action table that describes a single DSCP used for marking.')
diffServDscpMarkActDscp = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 3, 1, 1), Dscp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServDscpMarkActDscp.setStatus('current')
if mibBuilder.loadTexts: diffServDscpMarkActDscp.setDescription('The DSCP that this Action will store into the DSCP field of the subject. It is quite possible that the only packets subject to this Action are already marked with this DSCP. Note also that Differentiated Services processing may result in packet being marked on both ingress to a network and on egress from it, and that ingress and egress can occur in the same router.')
diffServCountActNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 5, 4), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServCountActNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServCountActNextFree.setDescription('This object contains an unused value for diffServCountActId, or a zero to indicate that none exist.')
diffServCountActTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 5, 5), )
if mibBuilder.loadTexts: diffServCountActTable.setStatus('current')
if mibBuilder.loadTexts: diffServCountActTable.setDescription('This table contains counters for all the traffic passing through an action element.')
diffServCountActEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServCountActId"))
if mibBuilder.loadTexts: diffServCountActEntry.setStatus('current')
if mibBuilder.loadTexts: diffServCountActEntry.setDescription('An entry in the count action table describes a single set of traffic counters.')
diffServCountActId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServCountActId.setStatus('current')
if mibBuilder.loadTexts: diffServCountActId.setDescription('An index that enumerates the Count Action entries. Managers obtain new values for row creation in this table by reading diffServCountActNextFree.')
diffServCountActOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServCountActOctets.setStatus('current')
if mibBuilder.loadTexts: diffServCountActOctets.setDescription('The number of octets at the Action data path element. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServCountActPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1, 3), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServCountActPkts.setStatus('current')
if mibBuilder.loadTexts: diffServCountActPkts.setDescription('The number of packets at the Action data path element. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServCountActStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServCountActStorage.setStatus('current')
if mibBuilder.loadTexts: diffServCountActStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServCountActStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 5, 5, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServCountActStatus.setStatus('current')
if mibBuilder.loadTexts: diffServCountActStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServAlgDrop = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 6))
diffServAlgDropNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 6, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServAlgDropNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropNextFree.setDescription('This object contains an unused value for diffServAlgDropId, or a zero to indicate that none exist.')
diffServAlgDropTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 6, 2), )
if mibBuilder.loadTexts: diffServAlgDropTable.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropTable.setDescription('The algorithmic drop table contains entries describing an element that drops packets according to some algorithm.')
diffServAlgDropEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServAlgDropId"))
if mibBuilder.loadTexts: diffServAlgDropEntry.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropEntry.setDescription('An entry describes a process that drops packets according to some algorithm. Further details of the algorithm type are to be found in diffServAlgDropType and with more detail parameter entry pointed to by diffServAlgDropSpecific when necessary.')
diffServAlgDropId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServAlgDropId.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropId.setDescription('An index that enumerates the Algorithmic Dropper entries. Managers obtain new values for row creation in this table by reading diffServAlgDropNextFree.')
diffServAlgDropType = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5))).clone(namedValues=NamedValues(("other", 1), ("tailDrop", 2), ("headDrop", 3), ("randomDrop", 4), ("alwaysDrop", 5)))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropType.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropType.setDescription("The type of algorithm used by this dropper. The value other(1) requires further specification in some other MIB module. In the tailDrop(2) algorithm, diffServAlgDropQThreshold represents the maximum depth of the queue, pointed to by diffServAlgDropQMeasure, beyond which all newly arriving packets will be dropped. In the headDrop(3) algorithm, if a packet arrives when the current depth of the queue, pointed to by diffServAlgDropQMeasure, is at diffServAlgDropQThreshold, packets currently at the head of the queue are dropped to make room for the new packet to be enqueued at the tail of the queue. In the randomDrop(4) algorithm, on packet arrival, an Active Queue Management algorithm is executed which may randomly drop a packet. This algorithm may be proprietary, and it may drop either the arriving packet or another packet in the queue. diffServAlgDropSpecific points to a diffServRandomDropEntry that describes the algorithm. For this algorithm, diffServAlgDropQThreshold is understood to be the absolute maximum size of the queue and additional parameters are described in diffServRandomDropTable. The alwaysDrop(5) algorithm is as its name specifies; always drop. In this case, the other configuration values in this Entry are not meaningful; There is no useful 'next' processing step, there is no queue, and parameters describing the queue are not useful. Therefore, diffServAlgDropNext, diffServAlgDropMeasure, and diffServAlgDropSpecific are all zeroDotZero.")
diffServAlgDropNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 3), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropNext.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropNext.setDescription('This selects the next Differentiated Services Functional Data Path Element to handle traffic for this data path. This RowPointer should point to an instance of one of: diffServClfrEntry diffServMeterEntry diffServActionEntry diffServQEntry A value of zeroDotZero in this attribute indicates no further Differentiated Services treatment is performed on traffic of this data path. The use of zeroDotZero is the normal usage for the last functional data path element of the current data path. When diffServAlgDropType is alwaysDrop(5), this object is ignored. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServAlgDropQMeasure = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropQMeasure.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropQMeasure.setDescription('Points to an entry in the diffServQTable to indicate the queue that a drop algorithm is to monitor when deciding whether to drop a packet. If the row pointed to does not exist, the algorithmic dropper element is considered inactive. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServAlgDropQThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('Bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropQThreshold.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropQThreshold.setDescription('A threshold on the depth in bytes of the queue being measured at which a trigger is generated to the dropping algorithm, unless diffServAlgDropType is alwaysDrop(5) where this object is ignored. For the tailDrop(2) or headDrop(3) algorithms, this represents the depth of the queue, pointed to by diffServAlgDropQMeasure, at which the drop action will take place. Other algorithms will need to define their own semantics for this threshold.')
diffServAlgDropSpecific = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 6), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropSpecific.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropSpecific.setDescription('Points to a table entry that provides further detail regarding a drop algorithm. Entries with diffServAlgDropType equal to other(1) may have this point to a table defined in another MIB module. Entries with diffServAlgDropType equal to randomDrop(4) must have this point to an entry in diffServRandomDropTable. For all other algorithms specified in this MIB, this should take the value zeroDotZero. The diffServAlgDropType is authoritative for the type of the drop algorithm and the specific parameters for the drop algorithm needs to be evaluated based on the diffServAlgDropType. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServAlgDropOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 7), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServAlgDropOctets.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropOctets.setDescription('The number of octets that have been deterministically dropped by this drop process. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServAlgDropPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 8), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServAlgDropPkts.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropPkts.setDescription('The number of packets that have been deterministically dropped by this drop process. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServAlgRandomDropOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 9), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServAlgRandomDropOctets.setStatus('current')
if mibBuilder.loadTexts: diffServAlgRandomDropOctets.setDescription('The number of octets that have been randomly dropped by this drop process. This counter applies, therefore, only to random droppers. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServAlgRandomDropPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 10), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServAlgRandomDropPkts.setStatus('current')
if mibBuilder.loadTexts: diffServAlgRandomDropPkts.setDescription('The number of packets that have been randomly dropped by this drop process. This counter applies, therefore, only to random droppers. Discontinuities in the value of this counter can occur at re- initialization of the management system and at other times as indicated by the value of ifCounterDiscontinuityTime on the relevant interface.')
diffServAlgDropStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 11), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropStorage.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServAlgDropStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 2, 1, 12), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServAlgDropStatus.setStatus('current')
if mibBuilder.loadTexts: diffServAlgDropStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServRandomDropNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 6, 3), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServRandomDropNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropNextFree.setDescription('This object contains an unused value for diffServRandomDropId, or a zero to indicate that none exist.')
diffServRandomDropTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 6, 4), )
if mibBuilder.loadTexts: diffServRandomDropTable.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropTable.setDescription('The random drop table contains entries describing a process that drops packets randomly. Entries in this table are pointed to by diffServAlgDropSpecific.')
diffServRandomDropEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServRandomDropId"))
if mibBuilder.loadTexts: diffServRandomDropEntry.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropEntry.setDescription('An entry describes a process that drops packets according to a random algorithm.')
diffServRandomDropId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServRandomDropId.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropId.setDescription('An index that enumerates the Random Drop entries. Managers obtain new values for row creation in this table by reading diffServRandomDropNextFree.')
diffServRandomDropMinThreshBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropMinThreshBytes.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropMinThreshBytes.setDescription('The average queue depth in bytes, beyond which traffic has a non-zero probability of being dropped. Changes in this variable may or may not be reflected in the reported value of diffServRandomDropMinThreshPkts.')
diffServRandomDropMinThreshPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('packets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropMinThreshPkts.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropMinThreshPkts.setDescription('The average queue depth in packets, beyond which traffic has a non-zero probability of being dropped. Changes in this variable may or may not be reflected in the reported value of diffServRandomDropMinThreshBytes.')
diffServRandomDropMaxThreshBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropMaxThreshBytes.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropMaxThreshBytes.setDescription('The average queue depth beyond which traffic has a probability indicated by diffServRandomDropProbMax of being dropped or marked. Note that this differs from the physical queue limit, which is stored in diffServAlgDropQThreshold. Changes in this variable may or may not be reflected in the reported value of diffServRandomDropMaxThreshPkts.')
diffServRandomDropMaxThreshPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('packets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropMaxThreshPkts.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropMaxThreshPkts.setDescription('The average queue depth beyond which traffic has a probability indicated by diffServRandomDropProbMax of being dropped or marked. Note that this differs from the physical queue limit, which is stored in diffServAlgDropQThreshold. Changes in this variable may or may not be reflected in the reported value of diffServRandomDropMaxThreshBytes.')
diffServRandomDropProbMax = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 1000))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropProbMax.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropProbMax.setDescription('The worst case random drop probability, expressed in drops per thousand packets. For example, if in the worst case every arriving packet may be dropped (100%) for a period, this has the value 1000. Alternatively, if in the worst case only one percent (1%) of traffic may be dropped, it has the value 10.')
diffServRandomDropWeight = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 65536))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropWeight.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropWeight.setDescription('The weighting of past history in affecting the Exponentially Weighted Moving Average function that calculates the current average queue depth. The equation uses diffServRandomDropWeight/65536 as the coefficient for the new sample in the equation, and (65536 - diffServRandomDropWeight)/65536 as the coefficient of the old value. Implementations may limit the values of diffServRandomDropWeight to a subset of the possible range of values, such as powers of two. Doing this would facilitate implementation of the Exponentially Weighted Moving Average using shift instructions or registers.')
diffServRandomDropSamplingRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 1000000))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropSamplingRate.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropSamplingRate.setDescription('The number of times per second the queue is sampled for queue average calculation. A value of zero is used to mean that the queue is sampled approximately each time a packet is enqueued (or dequeued).')
diffServRandomDropStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 9), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropStorage.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServRandomDropStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 6, 4, 1, 10), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServRandomDropStatus.setStatus('current')
if mibBuilder.loadTexts: diffServRandomDropStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServQueue = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 7))
diffServQNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 7, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServQNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServQNextFree.setDescription('This object contains an unused value for diffServQId, or a zero to indicate that none exist.')
diffServQTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 7, 2), )
if mibBuilder.loadTexts: diffServQTable.setStatus('current')
if mibBuilder.loadTexts: diffServQTable.setDescription('The Queue Table enumerates the individual queues. Note that the MIB models queuing systems as composed of individual queues, one per class of traffic, even though they may in fact be structured as classes of traffic scheduled using a common calendar queue, or in other ways.')
diffServQEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServQId"))
if mibBuilder.loadTexts: diffServQEntry.setStatus('current')
if mibBuilder.loadTexts: diffServQEntry.setDescription('An entry in the Queue Table describes a single queue or class of traffic.')
diffServQId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServQId.setStatus('current')
if mibBuilder.loadTexts: diffServQId.setDescription('An index that enumerates the Queue entries. Managers obtain new values for row creation in this table by reading diffServQNextFree.')
diffServQNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 2), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServQNext.setStatus('current')
if mibBuilder.loadTexts: diffServQNext.setDescription('This selects the next Differentiated Services Scheduler. The RowPointer must point to a diffServSchedulerEntry. A value of zeroDotZero in this attribute indicates an incomplete diffServQEntry instance. In such a case, the entry has no operational effect, since it has no parameters to give it meaning. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServQMinRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 3), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServQMinRate.setStatus('current')
if mibBuilder.loadTexts: diffServQMinRate.setDescription('This RowPointer indicates the diffServMinRateEntry that the scheduler, pointed to by diffServQNext, should use to service this queue. If the row pointed to is zeroDotZero, the minimum rate and priority is unspecified. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServQMaxRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServQMaxRate.setStatus('current')
if mibBuilder.loadTexts: diffServQMaxRate.setDescription('This RowPointer indicates the diffServMaxRateEntry that the scheduler, pointed to by diffServQNext, should use to service this queue. If the row pointed to is zeroDotZero, the maximum rate is the line speed of the interface. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServQStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServQStorage.setStatus('current')
if mibBuilder.loadTexts: diffServQStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServQStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 7, 2, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServQStatus.setStatus('current')
if mibBuilder.loadTexts: diffServQStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServScheduler = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 1, 8))
diffServSchedulerNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 8, 1), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServSchedulerNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerNextFree.setDescription('This object contains an unused value for diffServSchedulerId, or a zero to indicate that none exist.')
diffServSchedulerTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 8, 2), )
if mibBuilder.loadTexts: diffServSchedulerTable.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerTable.setDescription('The Scheduler Table enumerates packet schedulers. Multiple scheduling algorithms can be used on a given data path, with each algorithm described by one diffServSchedulerEntry.')
diffServSchedulerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServSchedulerId"))
if mibBuilder.loadTexts: diffServSchedulerEntry.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerEntry.setDescription('An entry in the Scheduler Table describing a single instance of a scheduling algorithm.')
diffServSchedulerId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServSchedulerId.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerId.setDescription('An index that enumerates the Scheduler entries. Managers obtain new values for row creation in this table by reading diffServSchedulerNextFree.')
diffServSchedulerNext = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 2), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerNext.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerNext.setDescription('This selects the next Differentiated Services Functional Data Path Element to handle traffic for this data path. This normally is null (zeroDotZero), or points to a diffServSchedulerEntry or a diffServQEntry. However, this RowPointer may also point to an instance of: diffServClfrEntry, diffServMeterEntry, diffServActionEntry, diffServAlgDropEntry. It would point another diffServSchedulerEntry when implementing multiple scheduler methods for the same data path, such as having one set of queues scheduled by WRR and that group participating in a priority scheduling system in which other queues compete with it in that way. It might also point to a second scheduler in a hierarchical scheduling system. If the row pointed to is zeroDotZero, no further Differentiated Services treatment is performed on traffic of this data path. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServSchedulerMethod = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 3), AutonomousType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerMethod.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerMethod.setDescription('The scheduling algorithm used by this Scheduler. zeroDotZero indicates that this is unknown. Standard values for generic algorithms: diffServSchedulerPriority, diffServSchedulerWRR, and diffServSchedulerWFQ are specified in this MIB; additional values may be further specified in other MIBs.')
diffServSchedulerMinRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 4), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerMinRate.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerMinRate.setDescription('This RowPointer indicates the entry in diffServMinRateTable which indicates the priority or minimum output rate from this scheduler. This attribute is used only when there is more than one level of scheduler. When it has the value zeroDotZero, it indicates that no minimum rate or priority is imposed. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServSchedulerMaxRate = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 5), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerMaxRate.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerMaxRate.setDescription('This RowPointer indicates the entry in diffServMaxRateTable which indicates the maximum output rate from this scheduler. When more than one maximum rate applies (eg, when a multi-rate shaper is in view), it points to the first of those rate entries. This attribute is used only when there is more than one level of scheduler. When it has the value zeroDotZero, it indicates that no maximum rate is imposed. Setting this to point to a target that does not exist results in an inconsistentValue error. If the row pointed to is removed or becomes inactive by other means, the treatment is as if this attribute contains a value of zeroDotZero.')
diffServSchedulerStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerStorage.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServSchedulerStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServSchedulerStatus.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServSchedulers = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 3, 2))
diffServSchedulerPriority = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 2, 1))
if mibBuilder.loadTexts: diffServSchedulerPriority.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerPriority.setDescription('For use with diffServSchedulerMethod to indicate the Priority scheduling method. This is defined as an algorithm in which the presence of data in a queue or set of queues absolutely precludes dequeue from another queue or set of queues of lower priority. Note that attributes from diffServMinRateEntry of the queues/schedulers feeding this scheduler are used when determining the next packet to schedule.')
diffServSchedulerWRR = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 2, 2))
if mibBuilder.loadTexts: diffServSchedulerWRR.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerWRR.setDescription('For use with diffServSchedulerMethod to indicate the Weighted Round Robin scheduling method, defined as any algorithm in which a set of queues are visited in a fixed order, and varying amounts of traffic are removed from each queue in turn to implement an average output rate by class. Notice attributes from diffServMinRateEntry of the queues/schedulers feeding this scheduler are used when determining the next packet to schedule.')
diffServSchedulerWFQ = ObjectIdentity((1, 3, 6, 1, 2, 1, 97, 3, 2, 3))
if mibBuilder.loadTexts: diffServSchedulerWFQ.setStatus('current')
if mibBuilder.loadTexts: diffServSchedulerWFQ.setDescription('For use with diffServSchedulerMethod to indicate the Weighted Fair Queuing scheduling method, defined as any algorithm in which a set of queues are conceptually visited in some order, to implement an average output rate by class. Notice attributes from diffServMinRateEntry of the queues/schedulers feeding this scheduler are used when determining the next packet to schedule.')
diffServMinRateNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 8, 3), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServMinRateNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateNextFree.setDescription('This object contains an unused value for diffServMinRateId, or a zero to indicate that none exist.')
diffServMinRateTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 8, 4), )
if mibBuilder.loadTexts: diffServMinRateTable.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateTable.setDescription('The Minimum Rate Parameters Table enumerates individual sets of scheduling parameter that can be used/reused by Queues and Schedulers.')
diffServMinRateEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServMinRateId"))
if mibBuilder.loadTexts: diffServMinRateEntry.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateEntry.setDescription('An entry in the Minimum Rate Parameters Table describes a single set of scheduling parameters for use by one or more queues or schedulers.')
diffServMinRateId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServMinRateId.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateId.setDescription('An index that enumerates the Scheduler Parameter entries. Managers obtain new values for row creation in this table by reading diffServMinRateNextFree.')
diffServMinRatePriority = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMinRatePriority.setStatus('current')
if mibBuilder.loadTexts: diffServMinRatePriority.setDescription("The priority of this input to the associated scheduler, relative to the scheduler's other inputs. A queue or scheduler with a larger numeric value will be served before another with a smaller numeric value.")
diffServMinRateAbsolute = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMinRateAbsolute.setReference('ifSpeed, ifHighSpeed, Interface MIB, RFC 2863')
if mibBuilder.loadTexts: diffServMinRateAbsolute.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateAbsolute.setDescription('The minimum absolute rate, in kilobits/sec, that a downstream scheduler element should allocate to this queue. If the value is zero, then there is effectively no minimum rate guarantee. If the value is non-zero, the scheduler will assure the servicing of this queue to at least this rate. Note that this attribute value and that of diffServMinRateRelative are coupled: changes to one will affect the value of the other. They are linked by the following equation, in that setting one will change the other: diffServMinRateRelative = (diffServMinRateAbsolute*1000000)/ifSpeed or, if appropriate: diffServMinRateRelative = diffServMinRateAbsolute/ifHighSpeed')
diffServMinRateRelative = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMinRateRelative.setReference('ifSpeed, ifHighSpeed, Interface MIB, RFC 2863')
if mibBuilder.loadTexts: diffServMinRateRelative.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateRelative.setDescription('The minimum rate that a downstream scheduler element should allocate to this queue, relative to the maximum rate of the interface as reported by ifSpeed or ifHighSpeed, in units of 1/1000 of 1. If the value is zero, then there is effectively no minimum rate guarantee. If the value is non-zero, the scheduler will assure the servicing of this queue to at least this rate. Note that this attribute value and that of diffServMinRateAbsolute are coupled: changes to one will affect the value of the other. They are linked by the following equation, in that setting one will change the other: diffServMinRateRelative = (diffServMinRateAbsolute*1000000)/ifSpeed or, if appropriate: diffServMinRateRelative = diffServMinRateAbsolute/ifHighSpeed')
diffServMinRateStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMinRateStorage.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServMinRateStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 4, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMinRateStatus.setStatus('current')
if mibBuilder.loadTexts: diffServMinRateStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServMaxRateNextFree = MibScalar((1, 3, 6, 1, 2, 1, 97, 1, 8, 5), IndexIntegerNextFree()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServMaxRateNextFree.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateNextFree.setDescription('This object contains an unused value for diffServMaxRateId, or a zero to indicate that none exist.')
diffServMaxRateTable = MibTable((1, 3, 6, 1, 2, 1, 97, 1, 8, 6), )
if mibBuilder.loadTexts: diffServMaxRateTable.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateTable.setDescription('The Maximum Rate Parameter Table enumerates individual sets of scheduling parameter that can be used/reused by Queues and Schedulers.')
diffServMaxRateEntry = MibTableRow((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1), ).setIndexNames((0, "DIFFSERV-MIB", "diffServMaxRateId"), (0, "DIFFSERV-MIB", "diffServMaxRateLevel"))
if mibBuilder.loadTexts: diffServMaxRateEntry.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateEntry.setDescription('An entry in the Maximum Rate Parameter Table describes a single set of scheduling parameters for use by one or more queues or schedulers.')
diffServMaxRateId = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 1), IndexInteger())
if mibBuilder.loadTexts: diffServMaxRateId.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateId.setDescription('An index that enumerates the Maximum Rate Parameter entries. Managers obtain new values for row creation in this table by reading diffServMaxRateNextFree.')
diffServMaxRateLevel = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 32)))
if mibBuilder.loadTexts: diffServMaxRateLevel.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateLevel.setDescription("An index that indicates which level of a multi-rate shaper is being given its parameters. A multi-rate shaper has some number of rate levels. Frame Relay's dual rate specification refers to a 'committed' and an 'excess' rate; ATM's dual rate specification refers to a 'mean' and a 'peak' rate. This table is generalized to support an arbitrary number of rates. The committed or mean rate is level 1, the peak rate (if any) is the highest level rate configured, and if there are other rates they are distributed in monotonically increasing order between them.")
diffServMaxRateAbsolute = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setUnits('kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMaxRateAbsolute.setReference('ifSpeed, ifHighSpeed, Interface MIB, RFC 2863')
if mibBuilder.loadTexts: diffServMaxRateAbsolute.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateAbsolute.setDescription('The maximum rate in kilobits/sec that a downstream scheduler element should allocate to this queue. If the value is zero, then there is effectively no maximum rate limit and that the scheduler should attempt to be work conserving for this queue. If the value is non-zero, the scheduler will limit the servicing of this queue to, at most, this rate in a non-work-conserving manner. Note that this attribute value and that of diffServMaxRateRelative are coupled: changes to one will affect the value of the other. They are linked by the following equation, in that setting one will change the other: diffServMaxRateRelative = (diffServMaxRateAbsolute*1000000)/ifSpeed or, if appropriate: diffServMaxRateRelative = diffServMaxRateAbsolute/ifHighSpeed')
diffServMaxRateRelative = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1, 4294967295))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMaxRateRelative.setReference('ifSpeed, ifHighSpeed, Interface MIB, RFC 2863')
if mibBuilder.loadTexts: diffServMaxRateRelative.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateRelative.setDescription('The maximum rate that a downstream scheduler element should allocate to this queue, relative to the maximum rate of the interface as reported by ifSpeed or ifHighSpeed, in units of 1/1000 of 1. If the value is zero, then there is effectively no maximum rate limit and the scheduler should attempt to be work conserving for this queue. If the value is non-zero, the scheduler will limit the servicing of this queue to, at most, this rate in a non-work-conserving manner. Note that this attribute value and that of diffServMaxRateAbsolute are coupled: changes to one will affect the value of the other. They are linked by the following equation, in that setting one will change the other: diffServMaxRateRelative = (diffServMaxRateAbsolute*1000000)/ifSpeed or, if appropriate: diffServMaxRateRelative = diffServMaxRateAbsolute/ifHighSpeed')
diffServMaxRateThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 5), BurstSize()).setUnits('Bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMaxRateThreshold.setReference('Adaptive rate Shaper, RFC 2963')
if mibBuilder.loadTexts: diffServMaxRateThreshold.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateThreshold.setDescription('The number of bytes of queue depth at which the rate of a multi-rate scheduler will increase to the next output rate. In the last conceptual row for such a shaper, this threshold is ignored and by convention is zero.')
diffServMaxRateStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMaxRateStorage.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateStorage.setDescription("The storage type for this conceptual row. Conceptual rows having the value 'permanent' need not allow write-access to any columnar objects in the row.")
diffServMaxRateStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 97, 1, 8, 6, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServMaxRateStatus.setStatus('current')
if mibBuilder.loadTexts: diffServMaxRateStatus.setDescription("The status of this conceptual row. All writable objects in this row may be modified at any time. Setting this variable to 'destroy' when the MIB contains one or more RowPointers pointing to it results in destruction being delayed until the row is no longer used.")
diffServMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 2, 1))
diffServMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 97, 2, 2))
diffServMIBFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 97, 2, 1, 1)).setObjects(("IF-MIB", "ifCounterDiscontinuityGroup"), ("DIFFSERV-MIB", "diffServMIBDataPathGroup"), ("DIFFSERV-MIB", "diffServMIBClfrGroup"), ("DIFFSERV-MIB", "diffServMIBClfrElementGroup"), ("DIFFSERV-MIB", "diffServMIBMultiFieldClfrGroup"), ("DIFFSERV-MIB", "diffServMIBActionGroup"), ("DIFFSERV-MIB", "diffServMIBAlgDropGroup"), ("DIFFSERV-MIB", "diffServMIBQGroup"), ("DIFFSERV-MIB", "diffServMIBSchedulerGroup"), ("DIFFSERV-MIB", "diffServMIBMaxRateGroup"), ("DIFFSERV-MIB", "diffServMIBMinRateGroup"), ("DIFFSERV-MIB", "diffServMIBCounterGroup"), ("DIFFSERV-MIB", "diffServMIBMeterGroup"), ("DIFFSERV-MIB", "diffServMIBTBParamGroup"), ("DIFFSERV-MIB", "diffServMIBDscpMarkActGroup"), ("DIFFSERV-MIB", "diffServMIBRandomDropGroup"))

if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBFullCompliance = diffServMIBFullCompliance.setStatus('current')
if mibBuilder.loadTexts: diffServMIBFullCompliance.setDescription('When this MIB is implemented with support for read-create, then such an implementation can claim full compliance. Such devices can then be both monitored and configured with this MIB.')
diffServMIBReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 97, 2, 1, 2)).setObjects(("IF-MIB", "ifCounterDiscontinuityGroup"), ("DIFFSERV-MIB", "diffServMIBDataPathGroup"), ("DIFFSERV-MIB", "diffServMIBClfrGroup"), ("DIFFSERV-MIB", "diffServMIBClfrElementGroup"), ("DIFFSERV-MIB", "diffServMIBMultiFieldClfrGroup"), ("DIFFSERV-MIB", "diffServMIBActionGroup"), ("DIFFSERV-MIB", "diffServMIBAlgDropGroup"), ("DIFFSERV-MIB", "diffServMIBQGroup"), ("DIFFSERV-MIB", "diffServMIBSchedulerGroup"), ("DIFFSERV-MIB", "diffServMIBMaxRateGroup"), ("DIFFSERV-MIB", "diffServMIBMinRateGroup"), ("DIFFSERV-MIB", "diffServMIBCounterGroup"), ("DIFFSERV-MIB", "diffServMIBMeterGroup"), ("DIFFSERV-MIB", "diffServMIBTBParamGroup"), ("DIFFSERV-MIB", "diffServMIBDscpMarkActGroup"), ("DIFFSERV-MIB", "diffServMIBRandomDropGroup"))

if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBReadOnlyCompliance = diffServMIBReadOnlyCompliance.setStatus('current')
if mibBuilder.loadTexts: diffServMIBReadOnlyCompliance.setDescription('When this MIB is implemented without support for read-create (i.e. in read-only mode), then such an implementation can claim read-only compliance. Such a device can then be monitored but can not be configured with this MIB.')
diffServMIBDataPathGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 1)).setObjects(("DIFFSERV-MIB", "diffServDataPathStart"), ("DIFFSERV-MIB", "diffServDataPathStorage"), ("DIFFSERV-MIB", "diffServDataPathStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBDataPathGroup = diffServMIBDataPathGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBDataPathGroup.setDescription('The Data Path Group defines the MIB Objects that describe a functional data path.')
diffServMIBClfrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 2)).setObjects(("DIFFSERV-MIB", "diffServClfrNextFree"), ("DIFFSERV-MIB", "diffServClfrStorage"), ("DIFFSERV-MIB", "diffServClfrStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBClfrGroup = diffServMIBClfrGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBClfrGroup.setDescription('The Classifier Group defines the MIB Objects that describe the list the starts of individual classifiers.')
diffServMIBClfrElementGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 3)).setObjects(("DIFFSERV-MIB", "diffServClfrElementNextFree"), ("DIFFSERV-MIB", "diffServClfrElementPrecedence"), ("DIFFSERV-MIB", "diffServClfrElementNext"), ("DIFFSERV-MIB", "diffServClfrElementSpecific"), ("DIFFSERV-MIB", "diffServClfrElementStorage"), ("DIFFSERV-MIB", "diffServClfrElementStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBClfrElementGroup = diffServMIBClfrElementGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBClfrElementGroup.setDescription('The Classifier Element Group defines the MIB Objects that describe the classifier elements that make up a generic classifier.')
diffServMIBMultiFieldClfrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 4)).setObjects(("DIFFSERV-MIB", "diffServMultiFieldClfrNextFree"), ("DIFFSERV-MIB", "diffServMultiFieldClfrAddrType"), ("DIFFSERV-MIB", "diffServMultiFieldClfrDstAddr"), ("DIFFSERV-MIB", "diffServMultiFieldClfrDstPrefixLength"), ("DIFFSERV-MIB", "diffServMultiFieldClfrFlowId"), ("DIFFSERV-MIB", "diffServMultiFieldClfrSrcAddr"), ("DIFFSERV-MIB", "diffServMultiFieldClfrSrcPrefixLength"), ("DIFFSERV-MIB", "diffServMultiFieldClfrDscp"), ("DIFFSERV-MIB", "diffServMultiFieldClfrProtocol"), ("DIFFSERV-MIB", "diffServMultiFieldClfrDstL4PortMin"), ("DIFFSERV-MIB", "diffServMultiFieldClfrDstL4PortMax"), ("DIFFSERV-MIB", "diffServMultiFieldClfrSrcL4PortMin"), ("DIFFSERV-MIB", "diffServMultiFieldClfrSrcL4PortMax"), ("DIFFSERV-MIB", "diffServMultiFieldClfrStorage"), ("DIFFSERV-MIB", "diffServMultiFieldClfrStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBMultiFieldClfrGroup = diffServMIBMultiFieldClfrGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBMultiFieldClfrGroup.setDescription('The Multi-field Classifier Group defines the MIB Objects that describe a classifier element for matching on various fields of an IP and upper-layer protocol header.')
diffServMIBMeterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 5)).setObjects(("DIFFSERV-MIB", "diffServMeterNextFree"), ("DIFFSERV-MIB", "diffServMeterSucceedNext"), ("DIFFSERV-MIB", "diffServMeterFailNext"), ("DIFFSERV-MIB", "diffServMeterSpecific"), ("DIFFSERV-MIB", "diffServMeterStorage"), ("DIFFSERV-MIB", "diffServMeterStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBMeterGroup = diffServMIBMeterGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBMeterGroup.setDescription('The Meter Group defines the objects used in describing a generic meter element.')
diffServMIBTBParamGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 6)).setObjects(("DIFFSERV-MIB", "diffServTBParamNextFree"), ("DIFFSERV-MIB", "diffServTBParamType"), ("DIFFSERV-MIB", "diffServTBParamRate"), ("DIFFSERV-MIB", "diffServTBParamBurstSize"), ("DIFFSERV-MIB", "diffServTBParamInterval"), ("DIFFSERV-MIB", "diffServTBParamStorage"), ("DIFFSERV-MIB", "diffServTBParamStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBTBParamGroup = diffServMIBTBParamGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBTBParamGroup.setDescription('The Token-Bucket Meter Group defines the objects used in describing a token bucket meter element.')
diffServMIBActionGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 7)).setObjects(("DIFFSERV-MIB", "diffServActionNextFree"), ("DIFFSERV-MIB", "diffServActionNext"), ("DIFFSERV-MIB", "diffServActionSpecific"), ("DIFFSERV-MIB", "diffServActionStorage"), ("DIFFSERV-MIB", "diffServActionInterface"), ("DIFFSERV-MIB", "diffServActionStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBActionGroup = diffServMIBActionGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBActionGroup.setDescription('The Action Group defines the objects used in describing a generic action element.')
diffServMIBDscpMarkActGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 8)).setObjects(("DIFFSERV-MIB", "diffServDscpMarkActDscp"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBDscpMarkActGroup = diffServMIBDscpMarkActGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBDscpMarkActGroup.setDescription('The DSCP Mark Action Group defines the objects used in describing a DSCP Marking Action element.')
diffServMIBCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 9)).setObjects(("DIFFSERV-MIB", "diffServCountActOctets"), ("DIFFSERV-MIB", "diffServCountActPkts"), ("DIFFSERV-MIB", "diffServAlgDropOctets"), ("DIFFSERV-MIB", "diffServAlgDropPkts"), ("DIFFSERV-MIB", "diffServAlgRandomDropOctets"), ("DIFFSERV-MIB", "diffServAlgRandomDropPkts"), ("DIFFSERV-MIB", "diffServCountActStorage"), ("DIFFSERV-MIB", "diffServCountActStatus"), ("DIFFSERV-MIB", "diffServCountActNextFree"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBCounterGroup = diffServMIBCounterGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBCounterGroup.setDescription('A collection of objects providing information specific to packet-oriented network interfaces.')
diffServMIBAlgDropGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 10)).setObjects(("DIFFSERV-MIB", "diffServAlgDropNextFree"), ("DIFFSERV-MIB", "diffServAlgDropType"), ("DIFFSERV-MIB", "diffServAlgDropNext"), ("DIFFSERV-MIB", "diffServAlgDropQMeasure"), ("DIFFSERV-MIB", "diffServAlgDropQThreshold"), ("DIFFSERV-MIB", "diffServAlgDropSpecific"), ("DIFFSERV-MIB", "diffServAlgDropStorage"), ("DIFFSERV-MIB", "diffServAlgDropStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBAlgDropGroup = diffServMIBAlgDropGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBAlgDropGroup.setDescription('The Algorithmic Drop Group contains the objects that describe algorithmic dropper operation and configuration.')
diffServMIBRandomDropGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 11)).setObjects(("DIFFSERV-MIB", "diffServRandomDropNextFree"), ("DIFFSERV-MIB", "diffServRandomDropMinThreshBytes"), ("DIFFSERV-MIB", "diffServRandomDropMinThreshPkts"), ("DIFFSERV-MIB", "diffServRandomDropMaxThreshBytes"), ("DIFFSERV-MIB", "diffServRandomDropMaxThreshPkts"), ("DIFFSERV-MIB", "diffServRandomDropProbMax"), ("DIFFSERV-MIB", "diffServRandomDropWeight"), ("DIFFSERV-MIB", "diffServRandomDropSamplingRate"), ("DIFFSERV-MIB", "diffServRandomDropStorage"), ("DIFFSERV-MIB", "diffServRandomDropStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBRandomDropGroup = diffServMIBRandomDropGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBRandomDropGroup.setDescription('The Random Drop Group augments the Algorithmic Drop Group for random dropper operation and configuration.')
diffServMIBQGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 12)).setObjects(("DIFFSERV-MIB", "diffServQNextFree"), ("DIFFSERV-MIB", "diffServQNext"), ("DIFFSERV-MIB", "diffServQMinRate"), ("DIFFSERV-MIB", "diffServQMaxRate"), ("DIFFSERV-MIB", "diffServQStorage"), ("DIFFSERV-MIB", "diffServQStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBQGroup = diffServMIBQGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBQGroup.setDescription("The Queue Group contains the objects that describe an interface's queues.")
diffServMIBSchedulerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 13)).setObjects(("DIFFSERV-MIB", "diffServSchedulerNextFree"), ("DIFFSERV-MIB", "diffServSchedulerNext"), ("DIFFSERV-MIB", "diffServSchedulerMethod"), ("DIFFSERV-MIB", "diffServSchedulerMinRate"), ("DIFFSERV-MIB", "diffServSchedulerMaxRate"), ("DIFFSERV-MIB", "diffServSchedulerStorage"), ("DIFFSERV-MIB", "diffServSchedulerStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBSchedulerGroup = diffServMIBSchedulerGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBSchedulerGroup.setDescription('The Scheduler Group contains the objects that describe packet schedulers on interfaces.')
diffServMIBMinRateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 14)).setObjects(("DIFFSERV-MIB", "diffServMinRateNextFree"), ("DIFFSERV-MIB", "diffServMinRatePriority"), ("DIFFSERV-MIB", "diffServMinRateAbsolute"), ("DIFFSERV-MIB", "diffServMinRateRelative"), ("DIFFSERV-MIB", "diffServMinRateStorage"), ("DIFFSERV-MIB", "diffServMinRateStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBMinRateGroup = diffServMIBMinRateGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBMinRateGroup.setDescription("The Minimum Rate Parameter Group contains the objects that describe packet schedulers' minimum rate or priority guarantees.")
diffServMIBMaxRateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 97, 2, 2, 15)).setObjects(("DIFFSERV-MIB", "diffServMaxRateNextFree"), ("DIFFSERV-MIB", "diffServMaxRateAbsolute"), ("DIFFSERV-MIB", "diffServMaxRateRelative"), ("DIFFSERV-MIB", "diffServMaxRateThreshold"), ("DIFFSERV-MIB", "diffServMaxRateStorage"), ("DIFFSERV-MIB", "diffServMaxRateStatus"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    diffServMIBMaxRateGroup = diffServMIBMaxRateGroup.setStatus('current')
if mibBuilder.loadTexts: diffServMIBMaxRateGroup.setDescription("The Maximum Rate Parameter Group contains the objects that describe packet schedulers' maximum rate guarantees.")
mibBuilder.exportSymbols("DIFFSERV-MIB", diffServActionEntry=diffServActionEntry, diffServQMaxRate=diffServQMaxRate, diffServMIBMultiFieldClfrGroup=diffServMIBMultiFieldClfrGroup, diffServTBParamTable=diffServTBParamTable, diffServSchedulerNextFree=diffServSchedulerNextFree, diffServActionTable=diffServActionTable, diffServTBParamBurstSize=diffServTBParamBurstSize, diffServActionId=diffServActionId, diffServAction=diffServAction, diffServQStorage=diffServQStorage, diffServMIBMinRateGroup=diffServMIBMinRateGroup, diffServCountActStorage=diffServCountActStorage, diffServSchedulerStatus=diffServSchedulerStatus, diffServAlgDropTable=diffServAlgDropTable, diffServQNextFree=diffServQNextFree, diffServMinRateEntry=diffServMinRateEntry, diffServClfrStatus=diffServClfrStatus, diffServMIBRandomDropGroup=diffServMIBRandomDropGroup, diffServMIBQGroup=diffServMIBQGroup, diffServMeterSucceedNext=diffServMeterSucceedNext, diffServQEntry=diffServQEntry, diffServMultiFieldClfrStorage=diffServMultiFieldClfrStorage, diffServMaxRateThreshold=diffServMaxRateThreshold, diffServMultiFieldClfrNextFree=diffServMultiFieldClfrNextFree, diffServMultiFieldClfrDstPrefixLength=diffServMultiFieldClfrDstPrefixLength, diffServMeterTable=diffServMeterTable, diffServCountActNextFree=diffServCountActNextFree, diffServSchedulers=diffServSchedulers, diffServTBParamTrTCMAware=diffServTBParamTrTCMAware, diffServMeterId=diffServMeterId, diffServAlgRandomDropPkts=diffServAlgRandomDropPkts, diffServMultiFieldClfrDscp=diffServMultiFieldClfrDscp, diffServDataPathStatus=diffServDataPathStatus, diffServTBParamStatus=diffServTBParamStatus, diffServCountActStatus=diffServCountActStatus, diffServMIBMeterGroup=diffServMIBMeterGroup, diffServRandomDropMaxThreshBytes=diffServRandomDropMaxThreshBytes, diffServMultiFieldClfrDstAddr=diffServMultiFieldClfrDstAddr, diffServCountActTable=diffServCountActTable, diffServMeterNextFree=diffServMeterNextFree, diffServQueue=diffServQueue, diffServClfrElementNextFree=diffServClfrElementNextFree, diffServTBParamId=diffServTBParamId, diffServSchedulerWFQ=diffServSchedulerWFQ, diffServMinRateStorage=diffServMinRateStorage, diffServDscpMarkActTable=diffServDscpMarkActTable, diffServTBParamRate=diffServTBParamRate, diffServRandomDropNextFree=diffServRandomDropNextFree, diffServMIBAlgDropGroup=diffServMIBAlgDropGroup, diffServActionSpecific=diffServActionSpecific, diffServRandomDropMinThreshPkts=diffServRandomDropMinThreshPkts, diffServDataPathIfDirection=diffServDataPathIfDirection, diffServMultiFieldClfrAddrType=diffServMultiFieldClfrAddrType, diffServAlgDropId=diffServAlgDropId, diffServSchedulerWRR=diffServSchedulerWRR, diffServRandomDropWeight=diffServRandomDropWeight, diffServMultiFieldClfrSrcPrefixLength=diffServMultiFieldClfrSrcPrefixLength, diffServMIBClfrElementGroup=diffServMIBClfrElementGroup, diffServSchedulerMethod=diffServSchedulerMethod, diffServCountActId=diffServCountActId, diffServTBParam=diffServTBParam, diffServTBParamSimpleTokenBucket=diffServTBParamSimpleTokenBucket, diffServClfrNextFree=diffServClfrNextFree, diffServMIBReadOnlyCompliance=diffServMIBReadOnlyCompliance, diffServMultiFieldClfrTable=diffServMultiFieldClfrTable, diffServMeterStatus=diffServMeterStatus, diffServQMinRate=diffServQMinRate, diffServDataPathStorage=diffServDataPathStorage, diffServMaxRateNextFree=diffServMaxRateNextFree, diffServRandomDropEntry=diffServRandomDropEntry, diffServMinRateStatus=diffServMinRateStatus, diffServSchedulerMaxRate=diffServSchedulerMaxRate, diffServMIBTBParamGroup=diffServMIBTBParamGroup, diffServTBParamNextFree=diffServTBParamNextFree, IndexIntegerNextFree=IndexIntegerNextFree, diffServTBParamEntry=diffServTBParamEntry, diffServAlgDrop=diffServAlgDrop, diffServRandomDropProbMax=diffServRandomDropProbMax, diffServMIBConformance=diffServMIBConformance, diffServMultiFieldClfrStatus=diffServMultiFieldClfrStatus, diffServMIBGroups=diffServMIBGroups, diffServMultiFieldClfrSrcAddr=diffServMultiFieldClfrSrcAddr, diffServActionNextFree=diffServActionNextFree, diffServActionInterface=diffServActionInterface, diffServSchedulerEntry=diffServSchedulerEntry, diffServTBParamInterval=diffServTBParamInterval, diffServClfrElementNext=diffServClfrElementNext, diffServCountActEntry=diffServCountActEntry, diffServClfrEntry=diffServClfrEntry, diffServMIBSchedulerGroup=diffServMIBSchedulerGroup, diffServAlgDropPkts=diffServAlgDropPkts, diffServQStatus=diffServQStatus, diffServTBParamTswTCM=diffServTBParamTswTCM, diffServMultiFieldClfrSrcL4PortMin=diffServMultiFieldClfrSrcL4PortMin, diffServTBMeters=diffServTBMeters, diffServRandomDropStatus=diffServRandomDropStatus, diffServTBParamStorage=diffServTBParamStorage, diffServMaxRateEntry=diffServMaxRateEntry, diffServAlgDropType=diffServAlgDropType, diffServMIBActionGroup=diffServMIBActionGroup, diffServTBParamSrTCMBlind=diffServTBParamSrTCMBlind, diffServAlgDropStatus=diffServAlgDropStatus, diffServClfrTable=diffServClfrTable, diffServMinRateId=diffServMinRateId, diffServMultiFieldClfrId=diffServMultiFieldClfrId, diffServQId=diffServQId, diffServDscpMarkActDscp=diffServDscpMarkActDscp, diffServMinRateRelative=diffServMinRateRelative, diffServMIBCounterGroup=diffServMIBCounterGroup, diffServMinRatePriority=diffServMinRatePriority, diffServClassifier=diffServClassifier, diffServTBParamAvgRate=diffServTBParamAvgRate, diffServRandomDropSamplingRate=diffServRandomDropSamplingRate, diffServMIBDscpMarkActGroup=diffServMIBDscpMarkActGroup, IndexInteger=IndexInteger, diffServSchedulerNext=diffServSchedulerNext, diffServAlgDropEntry=diffServAlgDropEntry, diffServAlgDropOctets=diffServAlgDropOctets, diffServActionNext=diffServActionNext, diffServRandomDropTable=diffServRandomDropTable, diffServMIBMaxRateGroup=diffServMIBMaxRateGroup, diffServSchedulerMinRate=diffServSchedulerMinRate, diffServRandomDropMaxThreshPkts=diffServRandomDropMaxThreshPkts, diffServSchedulerStorage=diffServSchedulerStorage, diffServDataPathTable=diffServDataPathTable, diffServRandomDropId=diffServRandomDropId, diffServClfrElementStatus=diffServClfrElementStatus, diffServTBParamTrTCMBlind=diffServTBParamTrTCMBlind, diffServMultiFieldClfrDstL4PortMax=diffServMultiFieldClfrDstL4PortMax, diffServClfrElementId=diffServClfrElementId, diffServAlgDropQThreshold=diffServAlgDropQThreshold, diffServDscpMarkActEntry=diffServDscpMarkActEntry, diffServMIBDataPathGroup=diffServMIBDataPathGroup, diffServMIBAdmin=diffServMIBAdmin, diffServClfrElementPrecedence=diffServClfrElementPrecedence, diffServCountActOctets=diffServCountActOctets, diffServQTable=diffServQTable, diffServDataPathEntry=diffServDataPathEntry, diffServDataPathStart=diffServDataPathStart, diffServActionStorage=diffServActionStorage, diffServCountActPkts=diffServCountActPkts, diffServMinRateAbsolute=diffServMinRateAbsolute, diffServMaxRateLevel=diffServMaxRateLevel, diffServMaxRateAbsolute=diffServMaxRateAbsolute, diffServMultiFieldClfrSrcL4PortMax=diffServMultiFieldClfrSrcL4PortMax, diffServRandomDropStorage=diffServRandomDropStorage, diffServAlgDropNext=diffServAlgDropNext, diffServSchedulerTable=diffServSchedulerTable, diffServMultiFieldClfrDstL4PortMin=diffServMultiFieldClfrDstL4PortMin, diffServClfrElementTable=diffServClfrElementTable, diffServClfrElementEntry=diffServClfrElementEntry, diffServMaxRateRelative=diffServMaxRateRelative, diffServMeterEntry=diffServMeterEntry, diffServMeterSpecific=diffServMeterSpecific, diffServTBParamType=diffServTBParamType, diffServMib=diffServMib, diffServMeter=diffServMeter, diffServClfrId=diffServClfrId, diffServRandomDropMinThreshBytes=diffServRandomDropMinThreshBytes, diffServAlgDropNextFree=diffServAlgDropNextFree, diffServMIBObjects=diffServMIBObjects, PYSNMP_MODULE_ID=diffServMib, diffServTBParamSrTCMAware=diffServTBParamSrTCMAware, diffServSchedulerPriority=diffServSchedulerPriority, diffServMaxRateId=diffServMaxRateId, diffServMIBFullCompliance=diffServMIBFullCompliance, diffServMeterFailNext=diffServMeterFailNext, diffServDataPath=diffServDataPath, diffServClfrElementSpecific=diffServClfrElementSpecific, diffServAlgDropSpecific=diffServAlgDropSpecific, diffServAlgDropQMeasure=diffServAlgDropQMeasure, diffServMultiFieldClfrEntry=diffServMultiFieldClfrEntry, diffServMaxRateTable=diffServMaxRateTable, diffServAlgDropStorage=diffServAlgDropStorage, IfDirection=IfDirection, diffServClfrStorage=diffServClfrStorage, diffServMinRateNextFree=diffServMinRateNextFree, diffServMeterStorage=diffServMeterStorage, diffServAlgRandomDropOctets=diffServAlgRandomDropOctets, diffServScheduler=diffServScheduler, diffServSchedulerId=diffServSchedulerId, diffServMIBClfrGroup=diffServMIBClfrGroup, diffServMinRateTable=diffServMinRateTable, diffServMultiFieldClfrFlowId=diffServMultiFieldClfrFlowId, diffServMaxRateStorage=diffServMaxRateStorage, diffServMaxRateStatus=diffServMaxRateStatus, diffServMIBCompliances=diffServMIBCompliances, diffServQNext=diffServQNext, diffServMultiFieldClfrProtocol=diffServMultiFieldClfrProtocol, diffServActionStatus=diffServActionStatus, diffServClfrElementStorage=diffServClfrElementStorage)



"""Implements data models and algorithms for tracking interface flapping.

Flapping is normally only tracked/updated based on incoming link traps.
"""

from __future__ import annotations

import logging
from datetime import datetime, timedelta
from typing import TYPE_CHECKING, List, Optional, Tuple

from pydantic import BaseModel, BeforeValidator, Field, PlainSerializer
from typing_extensions import Annotated

from zino.config.models import PollDevice
from zino.statemodels import FlapState, InterfaceState, PortStateEvent

if TYPE_CHECKING:
    from zino.state import ZinoState

from zino.time import now

_logger = logging.getLogger(__name__)

IMMEDIATELY = timedelta(seconds=0)
# Constants from Zino 1
FLAP_THRESHOLD = 35
FLAP_CEILING = 256
FLAP_MIN = 1.5
FLAP_MULTIPLIER = 2
FLAP_INIT_VAL = 2
FLAP_DECREMENT = 0.5
FLAP_DECREMENT_INTERVAL_SECONDS = 300

DeviceName = str
InterfaceIndex = int
PortIndex = Annotated[
    Tuple[DeviceName, InterfaceIndex],
    # Apply customized Pydantic serializing logic to the tuple, which will be used as dict keys
    PlainSerializer(lambda x: f"{x[0]}:{x[1]}", return_type=str, when_used="json"),
    BeforeValidator(lambda x: x.split(":") if isinstance(x, str) else x),
]


class FlappingState(BaseModel):
    """Contains runtime flapping stats for a single port"""

    hist_val: float = FLAP_INIT_VAL
    first_flap: datetime = Field(default_factory=now)
    last_flap: datetime = Field(default_factory=now)
    flaps: int = 0
    last_age: Optional[datetime] = None
    flapped_above_threshold: bool = False
    in_active_flap_state: bool = False

    def update(self):
        """Updates flap stats for a single port.  Called when a link trap is processed."""
        self.age()
        new_histval = min(self.hist_val * FLAP_MULTIPLIER, FLAP_CEILING)
        self.hist_val = new_histval
        self.flaps += 1
        self.last_flap = now()

    def age(self):
        """Ages the flapping state of a port.

        This should be idempotent, i.e. it is time dependent and can be called whenever one pleases to update the
        flap statistics of a port.
        """
        timestamp = now()

        last = self.last_age or self.last_flap
        delta = (timestamp - last).total_seconds() / FLAP_DECREMENT_INTERVAL_SECONDS
        self.last_age = timestamp
        new_hist_val = self.hist_val ** (FLAP_DECREMENT**delta)
        self.hist_val = min(new_hist_val, FLAP_CEILING)

    def is_below_threshold(self):
        """Returns True if the current flap value is below the flapping threshold"""
        return self.hist_val < FLAP_THRESHOLD

    def is_flapping(self) -> bool:
        """Returns True if the current stats indicate that this interface has crossed the flapping threshold.

        This is not the same as 'a flapping state has been declared', but is an indicator that such a state could
        now be declared.
        """
        self.age()
        if self.hist_val < FLAP_MIN:
            return False
        if self.hist_val > FLAP_THRESHOLD:
            self.flapped_above_threshold = True
        if self.flapped_above_threshold:
            return True
        return False


class FlappingStates(BaseModel):
    """Contains all runtime stats for flapping states"""

    interfaces: dict[PortIndex, FlappingState] = {}

    def update_interface_flap(self, interface: PortIndex) -> FlappingState:
        """Updates the flapping stats for a port.

        If the port is not already being tracked, it initializes the stats for it.
        """
        if interface not in self.interfaces:
            return self.first_flap(interface)

        flap = self.interfaces[interface]
        flap.update()
        return flap

    def first_flap(self, interface: PortIndex) -> FlappingState:
        """Initializes flapping stats for a port the first time a link trap is received for it"""
        flap = FlappingState(
            hist_val=FLAP_INIT_VAL,
            flaps=1,
        )
        self.interfaces[interface] = flap
        return flap

    def unflap(self, interface: PortIndex) -> Optional[FlappingState]:
        """Removes all flapping stats tracking for a port, if they exist"""
        return self.interfaces.pop(interface, None)

    def is_flapping(self, interface: PortIndex) -> bool:
        """Returns True if the current stats indicate that the interface has crossed the flapping threshold.

        This is not the same as 'a flapping state has been declared', but is an indicator that such a state could
        now be declared.
        """
        if interface not in self.interfaces:
            return False

        return self.interfaces[interface].is_flapping()

    def was_flapping(self, interface: PortIndex) -> bool:
        """Answers whether a flapping threshold was ever exceeded in the lifetime of this stats instance.

        Once a port has been marked as non-flapping by aging below threshold, its stats record will be removed,
        and this will once again return False.
        """
        return interface in self.interfaces and self.interfaces[interface].flapped_above_threshold

    def get_flap_count(self, interface: PortIndex) -> int:
        """Returns the current flap count of an interface, or 0 if no flapping stats exist for it."""
        if interface not in self.interfaces:
            return 0
        return self.interfaces[interface].flaps

    def get_flap_value(self, interface: PortIndex) -> float:
        """Returns the current flap value of an interface, or 0 if no flapping stats exist for it."""
        if interface not in self.interfaces:
            return 0
        return self.interfaces[interface].hist_val

    def clear_flap(self, interface: PortIndex, user: str, state: ZinoState, polldev: PollDevice) -> None:
        """Clears the internal flapping state for a port, if it exists, and also updates an existing portstate event"""
        from zino.state import config

        self._clear_flap_internal(interface, user, "Flapstate manually cleared", state=state)

        router, ifindex = interface
        try:
            port = state.devices[router].ports[ifindex]
        except KeyError:
            return
        port.state = InterfaceState.FLAPPING  # to get logged state change
        from zino.tasks.linkstatetask import (
            LinkStateTask,  # local import to avoid import cycles
        )

        poller = LinkStateTask(device=polldev, state=state, config=config)
        poller.schedule_verification_of_single_port(ifindex, deadline=IMMEDIATELY, reason="clearflap")

    def _clear_flap_internal(self, interface: PortIndex, user: str, reason: str, state: ZinoState) -> None:
        """Clears the internal flapping state for a port, including its ongoing portstate event"""
        router, ifindex = interface
        event = state.events.get(router, ifindex, PortStateEvent)
        if not event or event.flapstate != FlapState.FLAPPING:
            return

        try:
            port = state.devices[router].ports[ifindex]
        except KeyError:
            return

        event = state.events.checkout(event.id)
        event.add_history(f"{user}\n{reason}")
        event.flapstate = FlapState.STABLE
        event.flaps = self.get_flap_count((router, ifindex))
        msg = f'{router}: intf "{port.ifdescr}" ix {port.ifindex}({port.ifalias}) {reason}'
        _logger.info(msg)
        event.add_log(msg)
        state.events.commit(event)

        self.unflap(interface)


async def age_flapping_states(state: ZinoState, polldevs: dict[str, PollDevice]):
    """Ages all flapping states in the given ZinoState.  Should be called every FLAP_DECREMENT_INTERVAL_SECONDS."""
    for index, flap in list(state.flapping.interfaces.items()):
        await age_single_interface_flapping_state(flap, index, state, polldevs)


async def age_single_interface_flapping_state(
    flap: FlappingState, index: PortIndex, state: ZinoState, polldevs: dict[str, PollDevice]
) -> None:
    """Ages a single interface's flapping state, and updates events if it is no longer flapping."""
    flap.age()
    if flap.is_below_threshold():
        # Flapping stats aged below threshold, interface is no longer considered flapping
        if state.flapping.was_flapping(index):
            await stabilize_flapping_state(flap, index, state, polldevs)

        state.flapping.unflap(index)


async def stabilize_flapping_state(
    flap: FlappingState, index: PortIndex, state: ZinoState, polldevs: dict[str, PollDevice]
):
    """Updates port state and corresponding event to indicate things are now stable, for a port that has stopped
    flapping.
    """
    from zino.state import config

    router_name, ifindex = index
    port = state.devices.get(router_name).ports.get(ifindex) if router_name in state.devices else None
    if port:
        msg = f'{router_name}: intf "{port.ifdescr}" ix {ifindex} stopped flapping (aging)'
    else:
        msg = f"{router_name}: ix {ifindex} stopped flapping (aging)"
    _logger.info(msg)
    # An operator may have closed a flapping port event prematurely, so we may need to update both the closed
    # event and an open event, following Zino 1 logic:
    events: List[PortStateEvent] = []
    if event := state.events.get_closed_event(router_name, ifindex, PortStateEvent):
        events.append(event)
    if event := state.events.get_or_create_event(router_name, ifindex, PortStateEvent):
        events.append(event)
    polldev = polldevs.get(router_name)
    for event in events:
        # If we don't have all the necessary information, revisit later (this could mean that this was called
        # just after process startup, before config or state was properly loaded)
        if not (polldev and polldev.address and polldev.priority and port):
            return

        # Original Zino comment says: Hm, if this is a new event, we need to set "state" and "opened".
        event.flapstate = FlapState.STABLE
        event.flaps = flap.flaps
        event.port = port.ifdescr
        event.portstate = port.state
        event.router = polldev.name
        event.polladdr = polldev.address
        event.priority = polldev.priority
        event.ifindex = ifindex
        event.descr = port.ifalias

        event.add_log(msg)

        state.events.commit(event)

    # Local import to avoid circular import
    from zino.tasks.linkstatetask import LinkStateTask

    old_state = port.state
    port.state = InterfaceState.FLAPPING
    poll = LinkStateTask(device=polldev, state=state, config=config)
    try:
        await poll.poll_single_interface(ifindex)
    except Exception:  # noqa
        port.state = old_state



"""Zino time related functions"""

from datetime import datetime, timezone


def now() -> datetime:
    """Returns current time as UTC time with timezone information"""
    return datetime.now(timezone.utc)
